summaryrefslogtreecommitdiffstats
path: root/kmymoney2/reports/reportaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/reports/reportaccount.h')
-rw-r--r--kmymoney2/reports/reportaccount.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kmymoney2/reports/reportaccount.h b/kmymoney2/reports/reportaccount.h
index 91db6a2..e3bf663 100644
--- a/kmymoney2/reports/reportaccount.h
+++ b/kmymoney2/reports/reportaccount.h
@@ -174,39 +174,39 @@ public:
TQString debugName( void ) const;
/**
* Whether this account is a 'top level' tqparent account. This means that
* it's tqparent is an account class, like asset, liability, expense or income
*
* @return bool True if this account is a top level tqparent account
*/
/*inline*/ bool isTopLevel( void ) const;
/**
* Returns the name of the top level tqparent account
*
* (See isTopLevel for a definition of 'top level tqparent')
*
* @return TQString The name of the top level tqparent account
*/
/*inline*/ TQString topParentName( void ) const;
/**
* Returns a report account containing the top tqparent account
*
* @return ReportAccount The account of the top tqparent
*/
ReportAccount topParent( void ) const;
/**
* Returns a report account containing the immediate tqparent account
*
* @return ReportAccount The account of the immediate tqparent
*/
- ReportAccount tqparent( void ) const;
+ ReportAccount parent( void ) const;
/**
* Returns the number of accounts in this account's hierarchy. If this is a
* Top Category, it returns 1. If it's tqparent is a Top Category, returns 2,
* etc.
*
* @return unsigned Hierarchy depth
@@ -174,39 +174,39 @@ public:
TQString debugName( void ) const;
/**
- * Whether this account is a 'top level' tqparent account. This means that
- * it's tqparent is an account class, like asset, liability, expense or income
+ * Whether this account is a 'top level' parent account. This means that
+ * it's parent is an account class, like asset, liability, expense or income
*
@@ -174,39 +174,39 @@ public:
*
- * @return bool True if this account is a top level tqparent account
+ * @return bool True if this account is a top level parent account
*/
/*inline*/ bool isTopLevel( void ) const;
@@ -174,39 +174,39 @@ public:
/*inline*/ bool isTopLevel( void ) const;
/**
- * Returns the name of the top level tqparent account
+ * Returns the name of the top level parent account
*
@@ -174,39 +174,39 @@ public:
*
- * (See isTopLevel for a definition of 'top level tqparent')
+ * (See isTopLevel for a definition of 'top level parent')
*
@@ -174,39 +174,39 @@ public:
*
- * @return TQString The name of the top level tqparent account
+ * @return TQString The name of the top level parent account
*/
/*inline*/ TQString topParentName( void ) const;
@@ -174,39 +174,39 @@ public:
/*inline*/ TQString topParentName( void ) const;
/**
- * Returns a report account containing the top tqparent account
+ * Returns a report account containing the top parent account
*
@@ -174,39 +174,39 @@ public:
*
- * @return ReportAccount The account of the top tqparent
+ * @return ReportAccount The account of the top parent
*/
ReportAccount topParent( void ) const;
@@ -174,39 +174,39 @@ public:
ReportAccount topParent( void ) const;
/**
- * Returns a report account containing the immediate tqparent account
+ * Returns a report account containing the immediate parent account
*
@@ -174,39 +174,39 @@ public:
*
- * @return ReportAccount The account of the immediate tqparent
+ * @return ReportAccount The account of the immediate parent
*/
@@ -174,39 +174,39 @@ public:
/**
* Returns the number of accounts in this account's hierarchy. If this is a
- * Top Category, it returns 1. If it's tqparent is a Top Category, returns 2,
+ * Top Category, it returns 1. If it's parent is a Top Category, returns 2,
* etc.
*